@@ -16,6 +16,7 @@ use bio_types::sequence::SequenceReadPairOrientation;
 use bv::BitVec;
 use byteorder::{ByteOrder, LittleEndian};
 use itertools::Itertools;
+use progress_logger::ProgressLogger;
 use rust_htslib::bam::{self, Read as BAMRead};
 use rust_htslib::bcf::{self, Read as BCFRead};
 
@@ -28,7 +29,7 @@ use crate::utils;
 use crate::utils::MiniLogProb;
 use crate::variants;
 use crate::variants::evidence::observation::{
-    IndelOperations, Observation, ObservationBuilder, ReadPosition, Strand,
+    Observation, ObservationBuilder, ReadPosition, Strand,
 };
 use crate::variants::evidence::realignment;
 use crate::variants::model;
@@ -105,7 +106,7 @@ impl<R: realignment::Realigner + Clone + std::marker::Send + std::marker::Sync>
             "READ_ORIENTATION",
             "READ_POSITION",
             "SOFTCLIPPED",
-            "INDEL_OPERATIONS",
+            "ALT_INDEL_OPERATIONS",
             "PAIRED",
         ] {
             header.push_record(
@@ -132,10 +133,10 @@ impl<R: realignment::Realigner + Clone + std::marker::Send + std::marker::Sync>
         );
 
         Ok(if let Some(ref path) = self.outbcf {
-            bcf::Writer::from_path(path, &header, false, bcf::Format::BCF)
+            bcf::Writer::from_path(path, &header, false, bcf::Format::Bcf)
                 .context(format!("Unable to write BCF to {}.", path.display()))?
         } else {
-            bcf::Writer::from_stdout(&header, false, bcf::Format::BCF)
+            bcf::Writer::from_stdout(&header, false, bcf::Format::Bcf)
                 .context("Unable to write BCF to STDOUT.")?
         })
     }
@@ -146,7 +147,10 @@ impl<R: realignment::Realigner + Clone + std::marker::Send + std::marker::Sync>
         let mut skips = utils::SimpleCounter::default();
         let mut bcf_writer = self.writer()?;
         bcf_writer.set_threads(1)?;
-        let mut processed = 0;
+        let mut progress_logger = ProgressLogger::builder()
+            .with_items_name("records")
+            .with_frequency(std::time::Duration::from_secs(20))
+            .start();
 
         let mut bam_reader =
             bam::IndexedReader::from_path(&self.inbam).context("Unable to read BAM/CRAM file.")?;
@@ -177,6 +181,7 @@ impl<R: realignment::Realigner + Clone + std::marker::Send + std::marker::Sync>
             match bcf_reader.read(&mut record) {
                 None => {
                     display_skips(&skips);
+                    progress_logger.stop();
                     return Ok(());
                 }
                 Some(res) => res?,
@@ -199,11 +204,7 @@ impl<R: realignment::Realigner + Clone + std::marker::Send + std::marker::Sync>
 
                 for call in calls.iter() {
                     call.write_preprocessed_record(&mut bcf_writer)?;
-                    processed += 1;
-
-                    if processed % 100 == 0 {
-                        info!("{} records processed.", processed);
-                    }
+                    progress_logger.update(1u64);
                 }
             }
 
@@ -321,7 +322,7 @@ impl<R: realignment::Realigner + Clone + std::marker::Send + std::marker::Sync>
         variant: &model::Variant,
         work_item: &WorkItem,
         sample: &mut Sample,
-    ) -> Result<Option<Vec<Observation<ReadPosition, IndelOperations>>>> {
+    ) -> Result<Option<Vec<Observation<ReadPosition>>>> {
         let locus = || genome::Locus::new(work_item.chrom.clone(), work_item.start);
         let interval = |len: u64| {
             genome::Interval::new(
@@ -375,7 +376,6 @@ impl<R: realignment::Realigner + Clone + std::marker::Send + std::marker::Sync>
                 interval(ref_allele.len() as u64),
                 alt_allele.to_owned(),
                 self.realigner.clone(),
-                self.reference_buffer.seq(&work_item.chrom)?.as_ref(),
             ))?,
             model::Variant::Breakend {
                 ref_allele,
@@ -450,12 +450,12 @@ impl<R: realignment::Realigner + Clone + std::marker::Send + std::marker::Sync>
     }
 }
 
-pub(crate) static OBSERVATION_FORMAT_VERSION: &str = "8";
+pub(crate) static OBSERVATION_FORMAT_VERSION: &str = "9";
 
 /// Read observations from BCF record.
 pub(crate) fn read_observations(
     record: &mut bcf::Record,
-) -> Result<Vec<Observation<ReadPosition, IndelOperations>>> {
+) -> Result<Vec<Observation<ReadPosition>>> {
     fn read_values<T>(record: &mut bcf::Record, tag: &[u8]) -> Result<T>
     where
         T: serde::de::DeserializeOwned + Debug,
@@ -494,7 +494,7 @@ pub(crate) fn read_observations(
         read_values(record, b"READ_ORIENTATION")?;
     let read_position: Vec<ReadPosition> = read_values(record, b"READ_POSITION")?;
     let softclipped: BitVec<u8> = read_values(record, b"SOFTCLIPPED")?;
-    let indel_operations: Vec<IndelOperations> = read_values(record, b"INDEL_OPERATIONS")?;
+    let alt_indel_operations: BitVec<u8> = read_values(record, b"ALT_INDEL_OPERATIONS")?;
     let paired: BitVec<u8> = read_values(record, b"PAIRED")?;
 
     let obs = (0..prob_mapping.len())
@@ -511,7 +511,7 @@ pub(crate) fn read_observations(
                 .read_orientation(read_orientation[i])
                 .read_position(read_position[i])
                 .softclipped(softclipped[i as u64])
-                .indel_operations(indel_operations[i])
+                .has_alt_indel_operations(alt_indel_operations[i as u64])
                 .paired(paired[i as u64])
                 .build()
                 .unwrap()
@@ -522,7 +522,7 @@ pub(crate) fn read_observations(
 }
 
 pub(crate) fn write_observations(
-    observations: &[Observation<ReadPosition, IndelOperations>],
+    observations: &[Observation<ReadPosition>],
     record: &mut bcf::Record,
 ) -> Result<()> {
     let vec = || Vec::with_capacity(observations.len());
@@ -535,7 +535,7 @@ pub(crate) fn write_observations(
     let mut strand = Vec::with_capacity(observations.len());
     let mut read_orientation = Vec::with_capacity(observations.len());
     let mut softclipped: BitVec<u8> = BitVec::with_capacity(observations.len() as u64);
-    let mut indel_operations = Vec::with_capacity(observations.len());
+    let mut alt_indel_operations: BitVec<u8> = BitVec::with_capacity(observations.len() as u64);
     let mut paired: BitVec<u8> = BitVec::with_capacity(observations.len() as u64);
     let mut read_position = Vec::with_capacity(observations.len());
     let mut prob_hit_base = vec();
@@ -551,7 +551,7 @@ pub(crate) fn write_observations(
         strand.push(obs.strand);
         read_orientation.push(obs.read_orientation);
         softclipped.push(obs.softclipped);
-        indel_operations.push(obs.indel_operations);
+        alt_indel_operations.push(obs.has_alt_indel_operations);
         paired.push(obs.paired);
         read_position.push(obs.read_position);
     }
@@ -589,7 +589,7 @@ pub(crate) fn write_observations(
     push_values(record, b"STRAND", &strand)?;
     push_values(record, b"READ_ORIENTATION", &read_orientation)?;
     push_values(record, b"SOFTCLIPPED", &softclipped)?;
-    push_values(record, b"INDEL_OPERATIONS", &indel_operations)?;
+    push_values(record, b"ALT_INDEL_OPERATIONS", &alt_indel_operations)?;
     push_values(record, b"PAIRED", &paired)?;
     push_values(record, b"READ_POSITION", &read_position)?;
     push_values(record, b"PROB_HIT_BASE", &prob_hit_base)?;
@@ -607,7 +607,7 @@ pub(crate) fn remove_observation_header_entries(header: &mut bcf::Header) {
     header.remove_info(b"STRAND");
     header.remove_info(b"READ_ORIENTATION");
     header.remove_info(b"SOFTCLIPPED");
-    header.remove_info(b"INDEL_OPERATIONS");
+    header.remove_info(b"ALT_INDEL_OPERATIONS");
     header.remove_info(b"PAIRED");
     header.remove_info(b"PROB_HIT_BASE");
     header.remove_info(b"READ_POSITION");
