@@ -40,8 +40,8 @@ lazy_static! {
 }
 
 pub(crate) fn aux_tag_strand_info(record: &bam::Record) -> Option<&[u8]> {
-    if let Some(bam::record::Aux::String(strand_info)) = record.aux(b"SI") {
-        Some(strand_info)
+    if let Ok(bam::record::Aux::String(strand_info)) = record.aux(b"SI") {
+        Some(strand_info.as_bytes())
     } else {
         None
     }
