@@ -6,7 +6,7 @@ use itertools::Itertools;
 use strum::IntoEnumIterator;
 
 use crate::utils::PROB_095;
-use crate::variants::evidence::observation::{IndelOperations, Observation, ReadPosition};
+use crate::variants::evidence::observation::{Observation, ReadPosition};
 
 pub(crate) mod divindel_bias;
 pub(crate) mod read_orientation_bias;
@@ -20,14 +20,18 @@ pub(crate) use read_position_bias::ReadPositionBias;
 pub(crate) use softclip_bias::SoftclipBias;
 pub(crate) use strand_bias::StrandBias;
 
-pub(crate) trait Bias: Default + cmp::PartialEq {
-    fn prob(&self, observation: &Observation<ReadPosition, IndelOperations>) -> LogProb;
+pub(crate) trait Bias: Default + cmp::PartialEq + std::fmt::Debug {
+    fn prob(&self, observation: &Observation<ReadPosition>) -> LogProb;
 
-    fn prob_any(&self, observation: &Observation<ReadPosition, IndelOperations>) -> LogProb;
+    fn prob_any(&self, observation: &Observation<ReadPosition>) -> LogProb;
 
     fn is_artifact(&self) -> bool;
 
-    fn is_possible(&self, pileups: &[Vec<Observation<ReadPosition, IndelOperations>>]) -> bool {
+    fn is_possible(&self, pileups: &[Vec<Observation<ReadPosition>>]) -> bool {
+        if !self.is_artifact() {
+            return true;
+        }
+
         pileups.iter().any(|pileup| {
             pileup
                 .iter()
@@ -35,11 +39,11 @@ pub(crate) trait Bias: Default + cmp::PartialEq {
         })
     }
 
-    fn is_informative(&self, _pileups: &[Vec<Observation<ReadPosition, IndelOperations>>]) -> bool {
+    fn is_informative(&self, _pileups: &[Vec<Observation<ReadPosition>>]) -> bool {
         true
     }
 
-    fn is_bias_evidence(&self, observation: &Observation<ReadPosition, IndelOperations>) -> bool {
+    fn is_bias_evidence(&self, observation: &Observation<ReadPosition>) -> bool {
         self.prob(observation) != LogProb::ln_zero()
     }
 
@@ -47,8 +51,8 @@ pub(crate) trait Bias: Default + cmp::PartialEq {
         0.66666
     }
 
-    fn is_likely(&self, pileups: &[Vec<Observation<ReadPosition, IndelOperations>>]) -> bool {
-        if *self == Self::default() {
+    fn is_likely(&self, pileups: &[Vec<Observation<ReadPosition>>]) -> bool {
+        if !self.is_artifact() {
             true
         } else {
             pileups.iter().any(|pileup| {
@@ -61,6 +65,12 @@ pub(crate) trait Bias: Default + cmp::PartialEq {
                     // METHOD: there is bias evidence if we have at least two third of the strong observations supporting the bias
                     let ratio = strong_bias_evidence as f64 / strong_all as f64;
                     ratio >= self.min_strong_evidence_ratio()
+                } else if pileup.iter().all(|obs| Self::is_ref_obs(obs)) {
+                    // METHOD: if all obs are towards REF allele, there is no need to consider biases.
+                    // The variant will anyway be called as absent.
+                    // This can safe a lot of time and also avoids unexpected reporting
+                    // of artifacts in ambiguous cases.
+                    false
                 } else {
                     // METHOD: not enough reads, rather consider all biases to be sure
                     true
@@ -70,17 +80,21 @@ pub(crate) trait Bias: Default + cmp::PartialEq {
     }
 
     /// Learn parameters needed for estimation on current pileup.
-    fn learn_parameters(&mut self, _pileups: &[Vec<Observation<ReadPosition, IndelOperations>>]) {
+    fn learn_parameters(&mut self, _pileups: &[Vec<Observation<ReadPosition>>]) {
         // METHOD: by default, there is nothing to learn, however, a bias can use this to
         // infer some parameters over which we would otherwise need to integrate (which would hamper
         // performance too much).
     }
 
-    fn is_strong_obs(obs: &&Observation<ReadPosition, IndelOperations>) -> bool {
+    fn is_strong_obs(obs: &&Observation<ReadPosition>) -> bool {
         obs.prob_mapping() >= *PROB_095
             && BayesFactor::new(obs.prob_alt, obs.prob_ref).evidence_kass_raftery()
                 >= KassRaftery::Strong
     }
+
+    fn is_ref_obs(obs: &Observation<ReadPosition>) -> bool {
+        obs.prob_ref > obs.prob_alt
+    }
 }
 
 #[derive(Builder, CopyGetters, Getters, Debug, Clone, Ord, PartialOrd, Eq, PartialEq, Hash)]
@@ -189,10 +203,7 @@ impl Biases {
             .unwrap()
     }
 
-    pub(crate) fn is_possible(
-        &self,
-        pileups: &[Vec<Observation<ReadPosition, IndelOperations>>],
-    ) -> bool {
+    pub(crate) fn is_possible(&self, pileups: &[Vec<Observation<ReadPosition>>]) -> bool {
         self.strand_bias.is_possible(pileups)
             && self.read_orientation_bias.is_possible(pileups)
             && self.read_position_bias.is_possible(pileups)
@@ -200,10 +211,7 @@ impl Biases {
             && self.divindel_bias.is_possible(pileups)
     }
 
-    pub(crate) fn is_informative(
-        &self,
-        pileups: &[Vec<Observation<ReadPosition, IndelOperations>>],
-    ) -> bool {
+    pub(crate) fn is_informative(&self, pileups: &[Vec<Observation<ReadPosition>>]) -> bool {
         self.strand_bias.is_informative(pileups)
             && self.read_orientation_bias.is_informative(pileups)
             && self.read_position_bias.is_informative(pileups)
@@ -211,10 +219,7 @@ impl Biases {
             && self.divindel_bias.is_informative(pileups)
     }
 
-    pub(crate) fn is_likely(
-        &self,
-        pileups: &[Vec<Observation<ReadPosition, IndelOperations>>],
-    ) -> bool {
+    pub(crate) fn is_likely(&self, pileups: &[Vec<Observation<ReadPosition>>]) -> bool {
         self.strand_bias.is_likely(pileups)
             && self.read_orientation_bias.is_likely(pileups)
             && self.read_position_bias.is_likely(pileups)
@@ -222,8 +227,7 @@ impl Biases {
             && self.divindel_bias.is_likely(pileups)
     }
 
-    pub(crate) fn prob(&self, observation: &Observation<ReadPosition, IndelOperations>) -> LogProb {
-        //dbg!(self.strand_bias.prob(observation), self.read_orientation_bias.prob(observation), self.read_position_bias.prob(observation));
+    pub(crate) fn prob(&self, observation: &Observation<ReadPosition>) -> LogProb {
         self.strand_bias.prob(observation)
             + self.read_orientation_bias.prob(observation)
             + self.read_position_bias.prob(observation)
@@ -231,10 +235,7 @@ impl Biases {
             + self.divindel_bias.prob(observation)
     }
 
-    pub(crate) fn prob_any(
-        &self,
-        observation: &Observation<ReadPosition, IndelOperations>,
-    ) -> LogProb {
+    pub(crate) fn prob_any(&self, observation: &Observation<ReadPosition>) -> LogProb {
         self.strand_bias.prob_any(observation)
             + self.read_orientation_bias.prob_any(observation)
             + self.read_position_bias.prob_any(observation)
@@ -250,10 +251,7 @@ impl Biases {
             || self.divindel_bias.is_artifact()
     }
 
-    pub(crate) fn learn_parameters(
-        &mut self,
-        pileups: &[Vec<Observation<ReadPosition, IndelOperations>>],
-    ) {
+    pub(crate) fn learn_parameters(&mut self, pileups: &[Vec<Observation<ReadPosition>>]) {
         self.divindel_bias.learn_parameters(pileups)
     }
 }
