@@ -19,8 +19,7 @@ use rust_htslib::bam;
 
 use crate::estimation::alignment_properties;
 use crate::variants::evidence::observation::{
-    self, major_indel_operations, major_read_position, IndelOperations, Observable, Observation,
-    ReadPosition,
+    self, major_read_position, Observable, Observation, ReadPosition,
 };
 use crate::variants::model::VariantType;
 use crate::variants::{self, types::Variant};
@@ -127,7 +126,7 @@ impl Default for ProtocolStrandedness {
     }
 }
 
-pub(crate) type Pileup = Vec<Observation<ReadPosition, IndelOperations>>;
+pub(crate) type Pileup = Vec<Observation<ReadPosition>>;
 
 pub(crate) enum SubsampleCandidates {
     Necessary {
@@ -236,10 +235,9 @@ impl Sample {
         )?;
         // Process for each observation whether it is from the major read position or not.
         let major_pos = major_read_position(&observations);
-        let major_indel_ops = major_indel_operations(&observations);
         Ok(observations
             .iter()
-            .map(|obs| obs.process(major_pos, major_indel_ops.as_ref()))
+            .map(|obs| obs.process(major_pos))
             .collect())
     }
 }
